- Deprecate `~xotl.tools.iter_final_subclasses`:func: and
  `~xotl.tools.get_final_subclasses`:func:.

- Stop support for Python 3.4.

- Fix bug `#6`__: Instances of `~xotl.tools.symbols.boolean`:class: were not
  pickable.

  __ https://gitlab.merchise.org/merchise/xoutil/issues/6
